@@ -43,9 +43,10 @@
 #define ICE_STATE_ATTACK      2
 #define ICE_STATE_READER      3
 #define ICE_STATE_CONFIGCARD  4
-#define ICE_STATE_DUMP_SIM  5
+#define ICE_STATE_DUMP_SIM    5
+#define ICE_STATE_READ_SIM    6
 
-#define HF_ICLASS_NUM_MODES 6
+#define HF_ICLASS_NUM_MODES 7
 
 // ====================================================
 // Select which standalone function to be active.
@@ -56,6 +57,7 @@
 //#define ICE_USE               ICE_STATE_READER
 //#define ICE_USE               ICE_STATE_CONFIGCARD
 //#define ICE_USE               ICE_STATE_DUMP_SIM
+//#define ICE_USE               ICE_STATE_READ_SIM
 
 // ====================================================
 
@@ -720,6 +722,16 @@ void RunMod(void) {
                 mode = ICE_STATE_NONE;
                 break;
             }
+            case ICE_STATE_READ_SIM: {
+                DbpString("-=[ enter " _CYAN_("`read & sim`") " mode, read cards, then sim after button press ]=-");
+                DbpString("Entering reader dump mode");
+                reader_dump_mode();
+                SpinDelay(1200); // debounce button press
+                DbpString("Entering fullsim mode");
+                fullsim_mode();
+                DbpString("Exiting fullsim mode");
+                LEDsoff();
+            }
         }
     }
 
