@@ -58,34 +58,35 @@ static bool legic_xor(uint8_t *data, uint16_t cardsize) {
 }
 
 static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buffer) {
-    int i = 0, k = 0, segmentNum = 0, segment_len = 0, segment_flag = 0;
-    int crc = 0, wrp = 0, wrc = 0;
-    uint8_t stamp_len = 0;
-    char token_type[6] = {0, 0, 0, 0, 0, 0};
-    int dcf = 0;
-    int bIsSegmented = 0;
-    int return_value = PM3_SUCCESS;
 
     if (!(card_size == LEGIC_PRIME_MIM22 || card_size == LEGIC_PRIME_MIM256 || card_size == LEGIC_PRIME_MIM1024)) {
         PrintAndLogEx(FAILED, "Bytebuffer is not any known legic card size! (MIM22, MIM256, MIM1024)");
-        return_value = PM3_EFAILED;
         return PM3_EFAILED;
     }
 
     // copy input buffer into newly allocated buffer, because the existing code mutates the data inside.
     uint8_t *data = calloc(card_size, sizeof(uint8_t));
-    if (!data) {
+    if (data == NULL) {
         PrintAndLogEx(WARNING, "Cannot allocate memory");
         return PM3_EMALLOC;
     }
     memcpy(data, input_buffer, card_size);
 
+    int i = 0, k = 0, segmentNum = 0, segment_len = 0, segment_flag = 0;
+    int wrp = 0, wrc = 0, dcf = 0;
+    uint8_t stamp_len = 0;
+    char token_type[6] = {0, 0, 0, 0, 0, 0};
+    int bIsSegmented = 0;
+    int return_value = PM3_SUCCESS;
+
     // Output CDF System area (9 bytes) plus remaining header area (12 bytes)
-    crc = data[4];
+    int crc = data[4];
     uint32_t calc_crc = CRC8Legic(data, 4);
 
+    PrintAndLogEx(INFO, "--- " _CYAN_("Tag Information") " ----------------------------------------");
+    PrintAndLogEx(NORMAL, "");
     PrintAndLogEx(SUCCESS, " " _CYAN_("CDF: System Area"));
-    PrintAndLogEx(NORMAL, "------------------------------------------------------");
+    PrintAndLogEx(INFO, "------------------------------------------------------");
     PrintAndLogEx(SUCCESS, "MCD: " _GREEN_("%02X") " MSN: " _GREEN_("%s") " MCC: " _GREEN_("%02X") " ( %s )",
                   data[0],
                   sprint_hex(data + 1, 3),
@@ -134,7 +135,7 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
             stamp_len = 0xfc - data[6];
         }
 
-        PrintAndLogEx(SUCCESS, "DCF: %d (%02x %02x), Token Type=" _YELLOW_("%s") " (OLE=%01u), OL=%02u, FL=%02u",
+        PrintAndLogEx(SUCCESS, "DCF: %d (%02x %02x) Token Type=" _YELLOW_("%s") " (OLE=%01u) OL=%02u FL=%02u",
                       dcf,
                       data[5],
                       data[6],
@@ -153,7 +154,7 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
             strncpy(token_type, "IM", sizeof(token_type) - 1);
         }
 
-        PrintAndLogEx(SUCCESS, "DCF: %d (%02x %02x), Token Type = %s (OLE = %01u)",
+        PrintAndLogEx(SUCCESS, "DCF: %d (%02x %02x) Token Type = %s (OLE = %01u)",
                       dcf,
                       data[5],
                       data[6],
@@ -166,7 +167,7 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
     if (dcf != 0xFFFF) {
 
         if (bIsSegmented) {
-            PrintAndLogEx(SUCCESS, "WRP = %02u, WRC = %01u, RD = %01u, SSC = %02X",
+            PrintAndLogEx(SUCCESS, "WRP = %02u WRC = %01u RD = %01u SSC = %02X",
                           data[7] & 0x0f,
                           (data[7] & 0x70) >> 4,
                           (data[7] & 0x80) >> 7,
@@ -185,7 +186,7 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
             }
         }
     }
-    PrintAndLogEx(NORMAL, "------------------------------------------------------");
+    PrintAndLogEx(INFO, "------------------------------------------------------");
 
     uint8_t segCrcBytes[8] = {0, 0, 0, 0, 0, 0, 0, 0};
     uint32_t segCalcCRC = 0;
@@ -196,8 +197,9 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
         goto out;
     }
 
+    PrintAndLogEx(INFO, "");
     PrintAndLogEx(SUCCESS, _CYAN_("ADF: User Area"));
-    PrintAndLogEx(NORMAL, "------------------------------------------------------");
+    PrintAndLogEx(INFO, "------------------------------------------------------");
 
     if (bIsSegmented) {
 
@@ -208,8 +210,8 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
         for (segmentNum = 1; segmentNum < 128; segmentNum++) {
             // for decoding the segment header we need at least 4 bytes left in buffer
             if ((i + 4) > card_size) {
-                PrintAndLogEx(FAILED, "Cannot read segment header, because the input buffer is too small. "
-                              "Please check that the data is correct and properly aligned. ");
+                PrintAndLogEx(FAILED, "Cannot read segment header, because the input buffer is too small.");
+                PrintAndLogEx(FAILED, "Please check that the data is correct and properly aligned");
                 return_value = PM3_EOUTOFBOUND;
                 goto out;
             }
@@ -236,20 +238,20 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
             segCalcCRC = CRC8Legic(segCrcBytes, 8);
             segCRC = data[i + 4] ^ crc;
 
-            PrintAndLogEx(SUCCESS, "Segment     | " _YELLOW_("%02u"), segmentNum);
-            PrintAndLogEx(SUCCESS, "raw header  | 0x%02X 0x%02X 0x%02X 0x%02X",
+            PrintAndLogEx(SUCCESS, "Segment....... " _YELLOW_("%02u"), segmentNum);
+            PrintAndLogEx(SUCCESS, "Raw header.... 0x%02X 0x%02X 0x%02X 0x%02X",
                           data[i] ^ crc,
                           data[i + 1] ^ crc,
                           data[i + 2] ^ crc,
                           data[i + 3] ^ crc
                          );
-            PrintAndLogEx(SUCCESS, "Segment len | %u,  Flag: 0x%X (valid:%01u, last:%01u)",
+            PrintAndLogEx(SUCCESS, "Segment len... %u  Flag: 0x%X (valid:%01u last:%01u)",
                           segment_len,
                           segment_flag,
                           (segment_flag & 0x4) >> 2,
                           (segment_flag & 0x8) >> 3
                          );
-            PrintAndLogEx(SUCCESS, "            | WRP: %02u, WRC: %02u, RD: %01u, CRC: 0x%02X ( %s )",
+            PrintAndLogEx(SUCCESS, "              WRP: %02u WRC: %02u RD: %01u CRC: 0x%02X ( %s )",
                           wrp,
                           wrc,
                           ((data[i + 3] ^ crc) & 0x80) >> 7,
@@ -268,28 +270,33 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
             }
 
             if (hasWRC) {
-                PrintAndLogEx(SUCCESS, "\nWRC protected area:   (I %d | K %d| WRC %d)", i, k, wrc);
-                PrintAndLogEx(NORMAL, "\nrow  | data");
-                PrintAndLogEx(NORMAL, "-----+------------------------------------------------");
+                PrintAndLogEx(INFO, "");
+                PrintAndLogEx(SUCCESS, _CYAN_("WRC protected area:") "   (I %d | K %d| WRC %d)", i, k, wrc);
+                PrintAndLogEx(INFO, "");
+                PrintAndLogEx(INFO, "## | data                                            | ascii");
+                PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
 
                 for (k = i; k < (i + wrc); ++k)
                     data[k] ^= crc;
 
                 print_hex_break(data + i, wrc, 16);
-                PrintAndLogEx(NORMAL, "-----+------------------------------------------------\n");
+                PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
+                PrintAndLogEx(INFO, "");
                 i += wrc;
             }
 
             if (hasWRP) {
-                PrintAndLogEx(SUCCESS, "Remaining write protected area:  (I %d | K %d | WRC %d | WRP %d  WRP_LEN %d)", i, k, wrc, wrp, wrp_len);
-                PrintAndLogEx(NORMAL, "\nrow  | data");
-                PrintAndLogEx(NORMAL, "-----+------------------------------------------------");
+                PrintAndLogEx(SUCCESS, _CYAN_("Remaining write protected area:") "  (I %d | K %d | WRC %d | WRP %d  WRP_LEN %d)", i, k, wrc, wrp, wrp_len);
+                PrintAndLogEx(INFO, "");
+                PrintAndLogEx(INFO, "## | data                                            | ascii");
+                PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
 
                 for (k = i; k < (i + wrp_len); ++k)
                     data[k] ^= crc;
 
                 print_hex_break(data + i, wrp_len, 16);
-                PrintAndLogEx(NORMAL, "-----+------------------------------------------------\n");
+                PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
+                PrintAndLogEx(INFO, "");
                 i += wrp_len;
 
                 // does this one work? (Answer: Only if KGH/BGH is used with BCD encoded card number! So maybe this will show just garbage...)
@@ -302,15 +309,16 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
                 }
             }
             if (remain_seg_payload_len > 0) {
-                PrintAndLogEx(SUCCESS, "Remaining segment payload:  (I %d | K %d | Remain LEN %d)", i, k, remain_seg_payload_len);
-                PrintAndLogEx(NORMAL, "\nrow  | data");
-                PrintAndLogEx(NORMAL, "-----+------------------------------------------------");
+                PrintAndLogEx(SUCCESS, _CYAN_("Remaining segment payload:") "  (I %d | K %d | Remain LEN %d)", i, k, remain_seg_payload_len);
+                PrintAndLogEx(INFO, "");
+                PrintAndLogEx(INFO, "## | data                                            | ascii");
+                PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
 
                 for (k = i; k < (i + remain_seg_payload_len); ++k)
                     data[k] ^= crc;
 
                 print_hex_break(data + i, remain_seg_payload_len, 16);
-                PrintAndLogEx(NORMAL, "-----+------------------------------------------------\n");
+                PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------\n");
                 i += remain_seg_payload_len;
             }
             // end with last segment
@@ -331,7 +339,7 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
         int wrp_len = (wrp - wrc);
         int remain_seg_payload_len = (card_size - 22 - wrp);
 
-        PrintAndLogEx(SUCCESS, "Unsegmented card - WRP: %02u, WRC: %02u, RD: %01u",
+        PrintAndLogEx(SUCCESS, "Unsegmented card - WRP: %02u WRC: %02u RD: %01u",
                       wrp,
                       wrc,
                       (data[7] & 0x80) >> 7
@@ -346,20 +354,24 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
         }
 
         if (hasWRC) {
-            PrintAndLogEx(SUCCESS, "WRC protected area:   (I %d | WRC %d)", i, wrc);
-            PrintAndLogEx(NORMAL, "\nrow  | data");
-            PrintAndLogEx(NORMAL, "-----+------------------------------------------------");
+            PrintAndLogEx(SUCCESS, _CYAN_("WRC protected area:") "   (I %d | WRC %d)", i, wrc);
+            PrintAndLogEx(INFO, "");
+            PrintAndLogEx(INFO, "## | data                                            | ascii");
+            PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
             print_hex_break(data + i, wrc, 16);
-            PrintAndLogEx(NORMAL, "-----+------------------------------------------------\n");
+            PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
+            PrintAndLogEx(INFO, "");
             i += wrc;
         }
 
         if (hasWRP) {
-            PrintAndLogEx(SUCCESS, "Remaining write protected area:  (I %d | WRC %d | WRP %d | WRP_LEN %d)", i, wrc, wrp, wrp_len);
-            PrintAndLogEx(NORMAL, "\nrow  | data");
-            PrintAndLogEx(NORMAL, "-----+------------------------------------------------");
+            PrintAndLogEx(SUCCESS, _CYAN_("Remaining write protected area:") "  (I %d | WRC %d | WRP %d | WRP_LEN %d)", i, wrc, wrp, wrp_len);
+            PrintAndLogEx(INFO, "");
+            PrintAndLogEx(INFO, "## | data                                            | ascii");
+            PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
             print_hex_break(data + i, wrp_len, 16);
-            PrintAndLogEx(NORMAL, "-----+------------------------------------------------\n");
+            PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
+            PrintAndLogEx(INFO, "");
             i += wrp_len;
 
             // Q: does this one work?
@@ -374,11 +386,12 @@ static int decode_and_print_memory(uint16_t card_size, const uint8_t *input_buff
         }
 
         if (remain_seg_payload_len > 0) {
-            PrintAndLogEx(SUCCESS, "Remaining segment payload:  (I %d | Remain LEN %d)", i, remain_seg_payload_len);
-            PrintAndLogEx(NORMAL, "\nrow  | data");
-            PrintAndLogEx(NORMAL, "-----+------------------------------------------------");
+            PrintAndLogEx(SUCCESS, _CYAN_("Remaining segment payload:") "  (I %d | Remain LEN %d)", i, remain_seg_payload_len);
+            PrintAndLogEx(INFO, "");
+            PrintAndLogEx(INFO, "## | data                                            | ascii");
+            PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
             print_hex_break(data + i, remain_seg_payload_len, 16);
-            PrintAndLogEx(NORMAL, "-----+------------------------------------------------\n");
+            PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------\n");
         }
     }
 
@@ -400,9 +413,11 @@ static int CmdLegicInfo(const char *Cmd) {
 
     void *argtable[] = {
         arg_param_begin,
+        arg_lit0("v", "verbose", "verbose output"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, true);
+    bool verbose = arg_get_lit(ctx, 1);
     CLIParserFree(ctx);
 
     uint16_t datalen = 0;
@@ -418,7 +433,7 @@ static int CmdLegicInfo(const char *Cmd) {
 
     // allocate receiver buffer
     uint8_t *data = calloc(card.cardsize, sizeof(uint8_t));
-    if (!data) {
+    if (data == NULL) {
         PrintAndLogEx(WARNING, "Cannot allocate memory");
         return PM3_EMALLOC;
     }
@@ -430,8 +445,15 @@ static int CmdLegicInfo(const char *Cmd) {
         return status;
     }
 
-    decode_and_print_memory(card.cardsize, data);
+    if (verbose) {
+        PrintAndLogEx(NORMAL, "");
+        PrintAndLogEx(INFO, "## |  0  1  2  3  4  5  6  7  8  9  A  B  C  D  E  F | ascii");
+        PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
+        print_hex_break(data, datalen, 16);
+    }
 
+    PrintAndLogEx(NORMAL, "");
+    decode_and_print_memory(card.cardsize, data);
     free(data);
     return PM3_SUCCESS;
 }
@@ -536,20 +558,21 @@ static int CmdLegicSim(const char *Cmd) {
     SendCommandNG(CMD_HF_LEGIC_SIMULATE, (uint8_t *)&payload, sizeof(payload));
     PacketResponseNG resp;
 
-    PrintAndLogEx(INFO, "Press pm3-button to abort simulation");
-    bool keypress = kbd_enter_pressed();
-    while (keypress == false) {
-        keypress = kbd_enter_pressed();
+    PrintAndLogEx(INFO, "Press " _GREEN_("<Enter>") " or pm3-button to abort simulation");
+    for (;;) {
+        if (kbd_enter_pressed()) {
+            SendCommandNG(CMD_BREAK_LOOP, NULL, 0);
+            PrintAndLogEx(DEBUG, "User aborted");
+            break;
+        }
 
         if (WaitForResponseTimeout(CMD_HF_LEGIC_SIMULATE, &resp, 1500)) {
             break;
         }
-
     }
-    if (keypress)
-        SendCommandNG(CMD_BREAK_LOOP, NULL, 0);
 
     PrintAndLogEx(INFO, "Done");
+    PrintAndLogEx(HINT, "Try `" _YELLOW_("hf legic list") "` to view trace log");
     return PM3_SUCCESS;
 }
 
@@ -782,6 +805,9 @@ void legic_chk_iv(uint32_t *iv) {
 
 void legic_seteml(uint8_t *src, uint32_t offset, uint32_t numofbytes) {
 
+    PrintAndLogEx(INFO, "Uploading to emulator memory");
+    PrintAndLogEx(INFO, "." NOLF);
+
     // fast push mode
     g_conn.block_after_ACK = true;
     for (size_t i = offset; i < numofbytes; i += LEGIC_PACKET_SIZE) {
@@ -800,7 +826,11 @@ void legic_seteml(uint8_t *src, uint32_t offset, uint32_t numofbytes) {
         clearCommandBuffer();
         SendCommandNG(CMD_HF_LEGIC_ESET, (uint8_t *)payload, sizeof(legic_packet_t) + len);
         free(payload);
+        PrintAndLogEx(NORMAL, "." NOLF);
+        fflush(stdout);
     }
+    PrintAndLogEx(NORMAL, "");
+    PrintAndLogEx(SUCCESS, "uploaded " _YELLOW_("%d") " bytes to emulator memory", numofbytes);
 }
 
 static int CmdLegicReader(const char *Cmd) {
@@ -858,7 +888,7 @@ static int CmdLegicDump(const char *Cmd) {
     uint16_t dumplen = card.cardsize;
 
     legic_print_type(dumplen, 0);
-    PrintAndLogEx(SUCCESS, "Reading tag memory %d b...", dumplen);
+    PrintAndLogEx(SUCCESS, "Reading tag memory." NOLF);
 
     legic_packet_t *payload = calloc(1, sizeof(legic_packet_t));
     payload->offset = 0;
@@ -1077,10 +1107,11 @@ static int CmdLegicELoad(const char *Cmd) {
         legic_xor(dump, bytes_read);
     }
 
-    PrintAndLogEx(SUCCESS, "Uploading to emulator memory");
     legic_seteml(dump, 0, bytes_read);
 
     free(dump);
+
+    PrintAndLogEx(HINT, "You are ready to simulate. See " _YELLOW_("`hf legic sim -h`"));
     PrintAndLogEx(SUCCESS, "Done!");
     return PM3_SUCCESS;
 }
@@ -1174,6 +1205,7 @@ static int CmdLegicEView(const char *Cmd) {
         arg_lit0(NULL, "22", "LEGIC Prime MIM22"),
         arg_lit0(NULL, "256", "LEGIC Prime MIM256 (def)"),
         arg_lit0(NULL, "1024", "LEGIC Prime MIM1024"),
+        arg_lit0("v", "verbose", "verbose output"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, true);
@@ -1181,6 +1213,7 @@ static int CmdLegicEView(const char *Cmd) {
     bool m1 = arg_get_lit(ctx, 1);
     bool m2 = arg_get_lit(ctx, 2);
     bool m3 = arg_get_lit(ctx, 3);
+    bool verbose = arg_get_lit(ctx, 4);
     CLIParserFree(ctx);
 
     // validations
@@ -1212,10 +1245,16 @@ static int CmdLegicEView(const char *Cmd) {
         return PM3_ETIMEOUT;
     }
 
+    if (verbose) {
+        PrintAndLogEx(NORMAL, "");
+        PrintAndLogEx(INFO, "## |  0  1  2  3  4  5  6  7  8  9  A  B  C  D  E  F | ascii");
+        PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
+        print_hex_break(dump, bytes, 16);
+    }
+
     PrintAndLogEx(NORMAL, "");
-    PrintAndLogEx(INFO, "## |  0  1  2  3  4  5  6  7  8  9  A  B  C  D  E  F | ascii");
-    PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
-    print_hex_break(dump, bytes, 16);
+    decode_and_print_memory(bytes, dump);
+
     free(dump);
     return PM3_SUCCESS;
 }
@@ -1226,15 +1265,36 @@ static int CmdLegicEInfo(const char *Cmd) {
     CLIParserInit(&ctx, "hf legic einfo",
                   "It decodes and displays emulator memory",
                   "hf legic einfo\n"
+                  "hf legic eview --22\n"
                  );
     void *argtable[] = {
         arg_param_begin,
+        arg_lit0(NULL, "22", "LEGIC Prime MIM22"),
+        arg_lit0(NULL, "256", "LEGIC Prime MIM256 (def)"),
+        arg_lit0(NULL, "1024", "LEGIC Prime MIM1024"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, true);
+    bool m1 = arg_get_lit(ctx, 1);
+    bool m2 = arg_get_lit(ctx, 2);
+    bool m3 = arg_get_lit(ctx, 3);
     CLIParserFree(ctx);
 
+    // validations
+    if (m1 + m2 + m3 > 1) {
+        PrintAndLogEx(WARNING, "Only specify one LEGIC Prime Type");
+        return PM3_EINVARG;
+    } else if (m1 + m2 + m3 == 0) {
+        m2 = true;
+    }
+
     size_t card_size = LEGIC_PRIME_MIM256;
+    if (m1)
+        card_size = LEGIC_PRIME_MIM22;
+    else if (m2)
+        card_size = LEGIC_PRIME_MIM256;
+    else if (m3)
+        card_size = LEGIC_PRIME_MIM1024;
 
     uint8_t *dump = calloc(card_size, sizeof(uint8_t));
     if (dump == NULL) {
@@ -1347,12 +1407,14 @@ static int CmdLegicView(const char *Cmd) {
     void *argtable[] = {
         arg_param_begin,
         arg_str1("f", "file", "<fn>", "Filename of dump"),
+        arg_lit0("v", "verbose", "verbose output"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, false);
     int fnlen = 0;
     char filename[FILE_PATH_SIZE];
     CLIParamStrToBuf(arg_get_str(ctx, 1), (uint8_t *)filename, FILE_PATH_SIZE, &fnlen);
+    bool verbose = arg_get_lit(ctx, 2);
     CLIParserFree(ctx);
 
     // read dump file
@@ -1363,14 +1425,15 @@ static int CmdLegicView(const char *Cmd) {
         return res;
     }
 
-    PrintAndLogEx(NORMAL, "");
-    PrintAndLogEx(INFO, "## |  0  1  2  3  4  5  6  7  8  9  A  B  C  D  E  F | ascii");
-    PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
-    print_hex_break(dump, bytes_read, 16);
+    if (verbose) {
+        PrintAndLogEx(NORMAL, "");
+        PrintAndLogEx(INFO, "## |  0  1  2  3  4  5  6  7  8  9  A  B  C  D  E  F | ascii");
+        PrintAndLogEx(INFO, "---+-------------------------------------------------+-----------------");
+        print_hex_break(dump, bytes_read, 16);
+    }
 
     PrintAndLogEx(NORMAL, "");
     decode_and_print_memory(bytes_read, dump);
-
     free(dump);
     return PM3_SUCCESS;
 }
