@@ -27,12 +27,14 @@
 #include "comms.h"
 #include "usart_defs.h"
 #include "ui.h"
+#include "fpga.h"
 #include "cmdhw.h"
 #include "cmddata.h"
 #include "commonutil.h"
 #include "pm3_cmd.h"
 #include "pmflash.h"      // rdv40validation_t
 #include "cmdflashmem.h"  // get_signature..
+#include "uart/uart.h" // configure timeout
 
 static int CmdHelp(const char *Cmd);
 
@@ -689,7 +691,7 @@ static int CmdSetDivisor(const char *Cmd) {
     CLIParserFree(ctx);
 
     if (arg < 19) {
-        PrintAndLogEx(ERR, "Divisor must be between" _YELLOW_("19") " and " _YELLOW_("255"));
+        PrintAndLogEx(ERR, "Divisor must be between " _YELLOW_("19") " and " _YELLOW_("255"));
         return PM3_EINVARG;
     }
     // 12 000 000 (12MHz)
@@ -924,6 +926,46 @@ static int CmdTia(const char *Cmd) {
     return PM3_SUCCESS;
 }
 
+static int CmdTimeout(const char *Cmd) {
+
+    CLIParserContext *ctx;
+    CLIParserInit(&ctx, "hw timeout",
+                  "Set the communication timeout on the client side",
+                  "hw timeout --> Show current timeout\n"
+                  "hw timeout -t 20 --> Set the timeout to 20ms\n"
+                  "hw timeout -t 500 --> Set the timeout to 500ms\n"
+                 );
+
+    void *argtable[] = {
+        arg_param_begin,
+        arg_int0("t", "timeout", "<dec>", "timeout in ms"),
+        arg_param_end
+    };
+    CLIExecWithReturn(ctx, Cmd, argtable, true);
+    int32_t arg = arg_get_int_def(ctx, 1, -1);
+    CLIParserFree(ctx);
+
+    uint32_t oldTimeout = uart_get_timeouts();
+
+    // timeout is not given/invalid, just show the current timeout then return
+    if (arg < 0) {
+        PrintAndLogEx(INFO, "Current communication timeout: %ums", oldTimeout);
+        return PM3_SUCCESS;
+    }
+
+    uint32_t newTimeout = arg;
+    // UART_USB_CLIENT_RX_TIMEOUT_MS is considered as the minimum required timeout.
+    if (newTimeout < UART_USB_CLIENT_RX_TIMEOUT_MS) {
+        PrintAndLogEx(WARNING, "Timeout less than %ums might cause errors.", UART_USB_CLIENT_RX_TIMEOUT_MS);
+    } else if (newTimeout > 5000) {
+        PrintAndLogEx(WARNING, "Timeout greater than 5000ms makes the client unresponsive.");
+    }
+    uart_reconfigure_timeouts(newTimeout);
+    PrintAndLogEx(INFO, "Old communication timeout: %ums", oldTimeout);
+    PrintAndLogEx(INFO, "New communication timeout: %ums", newTimeout);
+    return PM3_SUCCESS;
+}
+
 static int CmdPing(const char *Cmd) {
     CLIParserContext *ctx;
     CLIParserInit(&ctx, "hw ping",
@@ -1042,6 +1084,23 @@ static int CmdBreak(const char *Cmd) {
     return PM3_SUCCESS;
 }
 
+int set_fpga_mode(uint8_t mode) {
+    if (mode < 1 || mode > 4) {
+        return PM3_EINVARG;
+    }
+    uint8_t d[] = {mode};
+    clearCommandBuffer();
+    SendCommandNG(CMD_SET_FPGAMODE, d, sizeof(d));
+    PacketResponseNG resp;
+    if (WaitForResponseTimeout(CMD_SET_FPGAMODE, &resp, 1000) == false) {
+        PrintAndLogEx(WARNING, "command execution timeout");
+        return PM3_ETIMEOUT;
+    }
+    if (resp.status != PM3_SUCCESS) {
+        PrintAndLogEx(ERR, "failed to set FPGA mode");
+    }
+    return resp.status;
+}
 
 static command_t CommandTable[] = {
     {"-------------", CmdHelp,         AlwaysAvailable, "----------------------- " _CYAN_("Hardware") " -----------------------"},
@@ -1062,6 +1121,7 @@ static command_t CommandTable[] = {
     {"status",        CmdStatus,       IfPm3Present,    "Show runtime status information about the connected Proxmark3"},
     {"tearoff",       CmdTearoff,      IfPm3Present,    "Program a tearoff hook for the next command supporting tearoff"},
     {"tia",           CmdTia,          IfPm3Present,    "Trigger a Timing Interval Acquisition to re-adjust the RealTimeCounter divider"},
+    {"timeout",       CmdTimeout,      AlwaysAvailable, "Set the communication timeout on the client side"},
     {"tune",          CmdTune,         IfPm3Present,    "Measure antenna tuning"},
     {"version",       CmdVersion,      AlwaysAvailable, "Show version information about the client and the connected Proxmark3, if any"},
     {NULL, NULL, NULL, NULL}
@@ -1234,7 +1294,7 @@ void pm3_version(bool verbose, bool oneliner) {
         return;
 
     PrintAndLogEx(NORMAL, "\n [ " _YELLOW_("Proxmark3 RFID instrument") " ]");
-    PrintAndLogEx(NORMAL, "\n [ " _YELLOW_("CLIENT") " ]");
+    PrintAndLogEx(NORMAL, "\n [ " _YELLOW_("Client") " ]");
     FormatVersionInformation(temp, sizeof(temp), "  ", &g_version_information);
     PrintAndLogEx(NORMAL, "%s", temp);
     PrintAndLogEx(NORMAL, "  compiled with............. " PM3CLIENTCOMPILER __VERSION__);
@@ -1273,7 +1333,7 @@ void pm3_version(bool verbose, bool oneliner) {
 #endif
 
     if (g_session.pm3_present) {
-        PrintAndLogEx(NORMAL, "\n [ " _YELLOW_("PROXMARK3") " ]");
+        PrintAndLogEx(NORMAL, "\n [ " _YELLOW_("Proxmark3") " ]");
 
         PacketResponseNG resp;
         clearCommandBuffer();
@@ -1333,7 +1393,7 @@ void pm3_version(bool verbose, bool oneliner) {
                 }
             }
             PrintAndLogEx(NORMAL,  payload->versionstr);
-            if (strstr(payload->versionstr, "2s30vq100") == NULL) {
+            if (strstr(payload->versionstr, FPGA_TYPE) == NULL) {
                 PrintAndLogEx(NORMAL, "  FPGA firmware... %s", _RED_("chip mismatch"));
             }
 
