@@ -32,12 +32,16 @@
 
 #define STRBOOL(p) ((p) ? "1" : "0")
 
-#define NDEF_WIFIAPPL_WSC "application/vnd.wfa.wsc"
-#define NDEF_WIFIAPPL_P2P "application/vnd.wfa.p2p"
-#define NDEF_BLUEAPPL     "application/vnd.bluetooth"
-#define NDEF_JSONAPPL     "application/json"
-#define NDEF_VCARDTEXT    "text/vcard"
-#define NDEF_XVCARDTEXT   "text/x-vcard"
+#define NDEF_WIFIAPPL_WSC    "application/vnd.wfa.wsc"
+#define NDEF_WIFIAPPL_P2P    "application/vnd.wfa.p2p"
+#define NDEF_JSONAPPL        "application/json"
+#define NDEF_VCARDTEXT       "text/vcard"
+#define NDEF_XVCARDTEXT      "text/x-vcard"
+
+#define NDEF_BLUEAPPL_EP        "application/vnd.bluetooth.ep.oob"
+#define NDEF_BLUEAPPL_LE        "application/vnd.bluetooth.le.oob"
+#define NDEF_BLUEAPPL_SECURE_LE "application/vnd.bluetooth.secure.le.oob"
+
 
 static const char *TypeNameFormat_s[] = {
     "Empty Record",
@@ -117,7 +121,7 @@ static int ndefDecodePayload(NDEFHeader_t *ndef, bool verbose);
 static uint16_t ndefTLVGetLength(const uint8_t *data, size_t *indx) {
     uint16_t len = 0;
     if (data[0] == 0xFF) {
-        len = (data[1] << 8) + data[2];
+        len = MemBeToUint2byte(data + 1);
         *indx += 3;
     } else {
         len = data[0];
@@ -270,7 +274,7 @@ static int ndef_print_signature(uint8_t *data, uint8_t data_len, uint8_t *signat
         return PM3_ESOFT;
     }
 
-    PrintAndLogEx(INFO, " IC signature public key name: %s", ndef_public_keys[i].desc);
+    PrintAndLogEx(INFO, " IC signature public key name: " _GREEN_("%s"), ndef_public_keys[i].desc);
     PrintAndLogEx(INFO, "IC signature public key value: %s", ndef_public_keys[i].value);
     PrintAndLogEx(INFO, "    Elliptic curve parameters: %s", get_curve_name(ndef_public_keys[i].grp_id));
     PrintAndLogEx(INFO, "               NDEF Signature: %s", sprint_hex_inrow(signature, 32));
@@ -854,6 +858,26 @@ static int ndefDecodeMime_json(NDEFHeader_t *ndef) {
     return PM3_SUCCESS;
 }
 
+static int ndefDecodeMime_bt_secure_le_oob(NDEFHeader_t *ndef) {
+    if (ndef->PayloadLen == 0) {
+        PrintAndLogEx(INFO, "no payload");
+        return PM3_SUCCESS;
+    }
+    PrintAndLogEx(INFO, "Type............ " _YELLOW_("%.*s"), (int)ndef->TypeLen, ndef->Type);
+    PrintAndLogEx(INFO, "To be implemented. Feel free to contribute!");
+    return PM3_SUCCESS;
+}
+
+static int ndefDecodeMime_bt_le_oob(NDEFHeader_t *ndef) {
+    if (ndef->PayloadLen == 0) {
+        PrintAndLogEx(INFO, "no payload");
+        return PM3_SUCCESS;
+    }
+    PrintAndLogEx(INFO, "Type............ " _YELLOW_("%.*s"), (int)ndef->TypeLen, ndef->Type);
+    PrintAndLogEx(INFO, "To be implemented. Feel free to contribute!");
+    return PM3_SUCCESS;
+}
+
 static int ndefDecodeMime_bt(NDEFHeader_t *ndef) {
     if (ndef->PayloadLen == 0) {
         PrintAndLogEx(INFO, "no payload");
@@ -1023,9 +1047,18 @@ static int ndefDecodePayload(NDEFHeader_t *ndef, bool verbose) {
             if (str_startswith(begin, NDEF_VCARDTEXT) || str_startswith(begin, NDEF_XVCARDTEXT)) {
                 ndefDecodeMime_vcard(ndef);
             }
-            if (str_startswith(begin, NDEF_BLUEAPPL)) {
+
+
+            if (str_startswith(begin, NDEF_BLUEAPPL_EP)) {
                 ndefDecodeMime_bt(ndef);
             }
+            if (str_startswith(begin, NDEF_BLUEAPPL_SECURE_LE)) {
+                ndefDecodeMime_bt_secure_le_oob(ndef);
+            }
+            if (str_startswith(begin, NDEF_BLUEAPPL_LE)) {
+                ndefDecodeMime_bt_le_oob(ndef);
+            }
+
             if (str_startswith(begin, NDEF_JSONAPPL)) {
                 ndefDecodeMime_json(ndef);
             }
