@@ -533,7 +533,7 @@ static int usage(void) {
     return 1;
 }
 
-int main(int argc, char *argv[]) {
+int main(int argc, const char *argv[]) {
     printf("\nMifare classic nested auth key recovery\n\n");
 
     if (argc < 9) return usage();
